==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlggauges.cpp <==
//
// C++ Implementation: dlggauges
//
// Description: 
//
//
// Author: Tomas Mecir <kmuddy@kmuddy.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "dlggauges.h"

#include "dlgeditgauge.h"

#include "../cgauge.h"
#include "../cgaugelist.h"

#include <qlabel.h>
#include <qlayout.h>

#include <kapp.h>
#include <kiconloader.h>
#include <klocale.h>
#include <klistbox.h>
#include <kmessagebox.h>
#include <kpushbutton.h>

dlgGauges::dlgGauges (cGaugeList *glist, QWidget *parent, const char *name) :
    KDialogBase (parent, name, true, i18n ("Status variables"), Ok, Ok, true)
{
  gl = glist;
  
  createDialog ();
}


dlgGauges::~dlgGauges()
{
}

void dlgGauges::createDialog ()
{
  //make dialog size 70% of main window size, or 350x250, whichever is bigger
  QSize wsize = (KApplication::kApplication())->mainWidget()->frameSize();
  int dlgx = wsize.width() * 7 / 10;
  int dlgy = wsize.height() * 7 / 10;
  if (dlgx < 350) dlgx = 350;
  if (dlgy < 250) dlgy = 250;
  
  //initial dialog size
  setInitialSize (QSize (dlgx, dlgy));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QGridLayout *layout = new QGridLayout (page, 2, 2);

  setMainWidget (page);

  //change button text
  setButtonOKText (i18n ("Done"));

  //create widgets
  QLabel *label = new QLabel (i18n ("&List of gauges"), page);
  box = new KListBox (page);
  label->setBuddy (box);
  QFrame *buttons = new QFrame (page);
  QVBoxLayout *buttonslayout = new QVBoxLayout (buttons);

  btadd = new KPushButton (i18n ("&Add..."), buttons);
  btmodify = new KPushButton (i18n ("&Modify..."), buttons);
  btdelete = new KPushButton (i18n ("&Delete"), buttons);

  KIconLoader *icons = (KApplication::kApplication())->iconLoader ();
  btup = new KPushButton (icons->loadIcon ("up", KIcon::Small),
        i18n ("Move &up"), buttons);
  btdown = new KPushButton (icons->loadIcon ("down", KIcon::Small),
        i18n ("Move &down"), buttons);

  buttonslayout->setSpacing (5);
  buttonslayout->addWidget (btadd);
  buttonslayout->addWidget (btmodify);
  buttonslayout->addWidget (btdelete);
  buttonslayout->addStretch (1);
  buttonslayout->addWidget (btup);
  buttonslayout->addWidget (btdown);
  buttonslayout->addStretch (10);

  layout->setColStretch (0, 10);
  layout->setRowStretch (1, 10);
  layout->setSpacing (5);

  //place out widgets
  layout->addWidget (label, 0, 0);
  layout->addWidget (box, 1, 0);
  layout->addWidget (buttons, 1, 1);

  //update the listbox
  updateMe ();

  //connect() the whole stuff!
  connect (btadd, SIGNAL (clicked ()), this, SLOT (add ()));
  connect (btmodify, SIGNAL (clicked ()), this, SLOT (modify ()));
  connect (btdelete, SIGNAL (clicked ()), this, SLOT (remove ()));
  connect (btup, SIGNAL (clicked ()), this, SLOT (up ()));
  connect (btdown, SIGNAL (clicked ()), this, SLOT (down ()));
  connect (box, SIGNAL (doubleClicked (QListBoxItem *)), this, SLOT (modify ()));
}

void dlgGauges::add ()
{
  //we show Edit timer dialog
  cGauge *gauge = new cGauge (gl->session ());
  dlgEditGauge *edit = new dlgEditGauge (gauge, this);

  //determine position for the new object
  int it = box->currentItem ();

  if (edit->showMe ())
  {
    //item now contains new data, so just add it to the list!
    if (it >= 0)
    {
      gl->reset ();
      for (int i = 0; i < it; i++)
        (*gl)++;
    } 
    if (it >= 0)
      gl->addAfterCurrent (gauge);
    else
      gl->addToEnd (gauge);
    gauge->recalc ();
    gl->gaugesChanged ();
    updateMe ();
  }
  else
    delete gauge;
  delete edit;

  if (it >= 0)
    it++;
  else
    it = gl->count () - 1;
  box->setSelected (it, true);
  box->setCurrentItem (it);
}

void dlgGauges::modify ()
{
  int it = box->currentItem ();
  if (it < 0) return;
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough
  gl->reset ();
  for (int i = 0; i < it; i++)
    (*gl)++;
  cGauge *gauge = (cGauge *) **gl;
  dlgEditGauge *edit = new dlgEditGauge (gauge, this);
  if (edit->showMe ())
  {
    //if he pressed OK, field already contains new data -> we only have to
    //update the listbox...
    updateMe ();
    gauge->recalc ();
    gl->gaugesChanged ();
  }
  delete edit;

  box->setSelected (it, true);
  box->setCurrentItem (it);
}

void dlgGauges::remove ()
{
  //get that item
  int it = box->currentItem ();
  if (it < 0) return;
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough

  //ask: really?
  int n = KMessageBox::questionYesNoCancel (this,
        i18n ("Do you really want to delete this gauge?"),
        i18n ("Delete gauge"));
  if (n == KMessageBox::Yes)
  {
    //really!
    //current item MUST be found AFTER the message box invocation; otherwise
    //some MXP <GAUGE> tag could modify that
    gl->reset ();
    for (int i = 0; i < it; i++)
      (*gl)++;
    gl->removeCurrent ();
    gl->gaugesChanged ();
    updateMe ();
  }
}

void dlgGauges::up ()
{
  int it = box->currentItem ();
  if (it < 0) return;
  if (it == 0) return;    //current item is the topmost one
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough
  gl->reset ();
  for (int i = 0; i < it; i++)
    (*gl)++;
  gl->moveCurrentToFront ();
  gl->gaugesChanged ();
  updateMe ();
  box->setCurrentItem (it - 1);
}

void dlgGauges::down ()
{
  int it = box->currentItem ();
  if (it < 0) return;
  if (it == box->count () - 1) return;    //current item is the bottommost one
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough
  gl->reset ();
  for (int i = 0; i < it; i++)
    (*gl)++;
  gl->moveCurrentToBack ();
  gl->gaugesChanged ();
  updateMe ();
  box->setCurrentItem (it + 1);
}

void dlgGauges::updateMe ()
{
  //remember old index
  int idx = box->currentItem ();

  box->clear ();
  for (gl->reset(); (*gl); (*gl)++)
  {
    cGauge *gauge = (cGauge *) **gl;
    
    QString name = "Variable: " + gauge->variable();
    if (!gauge->maxVariable().isEmpty())
      name += ", max.variable: " + gauge->maxVariable();
    if (!gauge->caption().isEmpty())
      name += ", caption: " + gauge->caption();
    if (gauge->hidden())
      name += " (hidden)";
    
    box->insertItem (name);
  }

  //make one item active, trying to be intelligent...
  box->setCurrentItem ((idx == -1) ? 0 : idx);
  if ((box->currentItem () == -1) && (idx != -1))
    box->setCurrentItem (idx - 1);
  if (box->currentItem () == -1)
    box->setCurrentItem (0);
}

#include "dlggauges.moc"

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlggauges.cpp <==
//
// C++ Implementation: dlggauges
//
// Description: 
//
//
// Author: Tomas Mecir <kmuddy@kmuddy.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "dlggauges.h"

#include "dlgeditgauge.h"

#include "cgauge.h"
#include "cgaugelist.h"

#include <qlabel.h>
#include <qlayout.h>

#include <kapp.h>
#include <kiconloader.h>
#include <klocale.h>
#include <klistbox.h>
#include <kmessagebox.h>
#include <kpushbutton.h>

dlgGauges::dlgGauges (cGaugeList *glist, QWidget *parent, const char *name) :
    KDialogBase (parent, name, true, i18n ("Status variables"), Ok, Ok, true)
{
  gl = glist;
  
  createDialog ();
}


dlgGauges::~dlgGauges()
{
}

void dlgGauges::createDialog ()
{
  //make dialog size 70% of main window size, or 350x250, whichever is bigger
  QSize wsize = (KApplication::kApplication())->mainWidget()->frameSize();
  int dlgx = wsize.width() * 7 / 10;
  int dlgy = wsize.height() * 7 / 10;
  if (dlgx < 350) dlgx = 350;
  if (dlgy < 250) dlgy = 250;
  
  //initial dialog size
  setInitialSize (QSize (dlgx, dlgy));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QGridLayout *layout = new QGridLayout (page, 2, 2);

  setMainWidget (page);

  //change button text
  setButtonOKText (i18n ("Done"));

  //create widgets
  QLabel *label = new QLabel (i18n ("&List of gauges"), page);
  box = new KListBox (page);
  label->setBuddy (box);
  QFrame *buttons = new QFrame (page);
  QVBoxLayout *buttonslayout = new QVBoxLayout (buttons);

  btadd = new KPushButton (i18n ("&Add..."), buttons);
  btmodify = new KPushButton (i18n ("&Modify..."), buttons);
  btdelete = new KPushButton (i18n ("&Delete"), buttons);

  KIconLoader *icons = (KApplication::kApplication())->iconLoader ();
  btup = new KPushButton (icons->loadIcon ("up", KIcon::Small),
        i18n ("Move &up"), buttons);
  btdown = new KPushButton (icons->loadIcon ("down", KIcon::Small),
        i18n ("Move &down"), buttons);

  buttonslayout->setSpacing (5);
  buttonslayout->addWidget (btadd);
  buttonslayout->addWidget (btmodify);
  buttonslayout->addWidget (btdelete);
  buttonslayout->addStretch (1);
  buttonslayout->addWidget (btup);
  buttonslayout->addWidget (btdown);
  buttonslayout->addStretch (10);

  layout->setColStretch (0, 10);
  layout->setRowStretch (1, 10);
  layout->setSpacing (5);

  //place out widgets
  layout->addWidget (label, 0, 0);
  layout->addWidget (box, 1, 0);
  layout->addWidget (buttons, 1, 1);

  //update the listbox
  updateMe ();

  //connect() the whole stuff!
  connect (btadd, SIGNAL (clicked ()), this, SLOT (add ()));
  connect (btmodify, SIGNAL (clicked ()), this, SLOT (modify ()));
  connect (btdelete, SIGNAL (clicked ()), this, SLOT (remove ()));
  connect (btup, SIGNAL (clicked ()), this, SLOT (up ()));
  connect (btdown, SIGNAL (clicked ()), this, SLOT (down ()));
  connect (box, SIGNAL (doubleClicked (QListBoxItem *)), this, SLOT (modify ()));
}

void dlgGauges::add ()
{
  //we show Edit timer dialog
  cGauge *gauge = new cGauge (gl->sess());
  dlgEditGauge *edit = new dlgEditGauge (gauge, this);

  //determine position for the new object
  int it = box->currentItem ();

  if (edit->showMe ())
  {
    //item now contains new data, so just add it to the list!
    if (it >= 0)
    {
      gl->reset ();
      for (int i = 0; i < it; i++)
        (*gl)++;
    } 
    if (it >= 0)
      gl->addAfterCurrent (gauge);
    else
      gl->addToEnd (gauge);
    gauge->recalc ();
    gl->gaugesChanged ();
    updateMe ();
  }
  else
    delete gauge;
  delete edit;

  if (it >= 0)
    it++;
  else
    it = gl->count () - 1;
  box->setSelected (it, true);
  box->setCurrentItem (it);
}

void dlgGauges::modify ()
{
  int it = box->currentItem ();
  if (it < 0) return;
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough
  gl->reset ();
  for (int i = 0; i < it; i++)
    (*gl)++;
  cGauge *gauge = (cGauge *) **gl;
  dlgEditGauge *edit = new dlgEditGauge (gauge, this);
  if (edit->showMe ())
  {
    //if he pressed OK, field already contains new data -> we only have to
    //update the listbox...
    updateMe ();
    gauge->recalc ();
    gl->gaugesChanged ();
  }
  delete edit;

  box->setSelected (it, true);
  box->setCurrentItem (it);
}

void dlgGauges::remove ()
{
  //get that item
  int it = box->currentItem ();
  if (it < 0) return;
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough

  //ask: really?
  int n = KMessageBox::questionYesNoCancel (this,
        i18n ("Do you really want to delete this gauge?"),
        i18n ("Delete gauge"));
  if (n == KMessageBox::Yes)
  {
    //really!
    //current item MUST be found AFTER the message box invocation; otherwise
    //some MXP <GAUGE> tag could modify that
    gl->reset ();
    for (int i = 0; i < it; i++)
      (*gl)++;
    gl->removeCurrent ();
    gl->gaugesChanged ();
    updateMe ();
  }
}

void dlgGauges::up ()
{
  int it = box->currentItem ();
  if (it < 0) return;
  if (it == 0) return;    //current item is the topmost one
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough
  gl->reset ();
  for (int i = 0; i < it; i++)
    (*gl)++;
  gl->moveCurrentToFront ();
  gl->gaugesChanged ();
  updateMe ();
  box->setCurrentItem (it - 1);
}

void dlgGauges::down ()
{
  int it = box->currentItem ();
  if (it < 0) return;
  if (it == box->count () - 1) return;    //current item is the bottommost one
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough
  gl->reset ();
  for (int i = 0; i < it; i++)
    (*gl)++;
  gl->moveCurrentToBack ();
  gl->gaugesChanged ();
  updateMe ();
  box->setCurrentItem (it + 1);
}

void dlgGauges::updateMe ()
{
  //remember old index
  int idx = box->currentItem ();

  box->clear ();
  for (gl->reset(); (*gl); (*gl)++)
  {
    cGauge *gauge = (cGauge *) **gl;
    
    QString name = "Variable: " + gauge->variable();
    if (!gauge->maxVariable().isEmpty())
      name += ", max.variable: " + gauge->maxVariable();
    if (!gauge->caption().isEmpty())
      name += ", caption: " + gauge->caption();
    if (gauge->hidden())
      name += " (hidden)";
    
    box->insertItem (name);
  }

  //make one item active, trying to be intelligent...
  box->setCurrentItem ((idx == -1) ? 0 : idx);
  if ((box->currentItem () == -1) && (idx != -1))
    box->setCurrentItem (idx - 1);
  if (box->currentItem () == -1)
    box->setCurrentItem (0);
}

#include "dlggauges.moc"
